ManiaExchange
=============

Information
-----------
Name:
  ``pyplanet.apps.contrib.mx``
Depends on:
  ``core.maniaplanet``
Game:
  Any

Features
--------
Adding maps from Mania-Exchange.

Commands
--------

Add map(s) from MX
~~~~~~~~~~~~~~~~~~

Set server password
~~~~~~~~~~~~~~~~~~~
Command:
  ``//add mx``
Parameters:
  * ManiaExchange ID(s). One or more with space between it.
Functionality:
  Adding maps from ManiaExchange to the server.
Required permission:
  ``mx:add_remote``, requires admin level 3.
